==> bbwa-0.0.4.tar.gz: bbwa-0.0.4/index_i.php <==
<?php
//
// BBWA
// index_i.php
// Хࡦեʤɤɽ ()
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<html>
<head>
<title>BBWA</title>
</head>
<body>


<?php
include("variables.php");
$fileArray = array();

// ĥԤ
function messageParse($message) {
  $message = stripslashes($message);
  $message = ereg_replace(
    "(http|https|ftp|mailto):[a-zA-Z0-9/%&=_:+~@\-\?\.]*",
    "<a href=\"\\0\">\\0</a>", $message);
  $message = ereg_replace("{{BR}}", "<br>", $message);
  $message = ereg_replace("{{LT}}", "&lt;", $message);
  $message = ereg_replace("{{GT}}", "&gt;", $message);

  return $message;
}

// 
$tempArray = array();
$dirHandle = opendir($dirName);
while ($fileList = readdir($dirHandle)) { 
  if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
    $tempArray[$fileList] = filemtime("${dirName}Messages/${fileList}_mes.txt");
  }
}
closedir($dirHandle);
arsort($tempArray);
$fileArray = array_keys($tempArray);

// ڡ׻
$pages = (int) ((count($fileArray) - 1) / 20 + 1);
if (isset($_GET['page'])) {
  $current = $_GET['page'];
} else {
  $current = 1;
}
$imgStart = ($current - 1) * 20;
$imgEnd = min(($imgStart + 20), count($fileArray));

// SJIS ǽ
mb_http_output("SJIS");
ob_start(mb_output_handler);

// ڡΥɽ
if(!isset($_GET['img'])) {
  print("ɽ<br>\n");
  if ($current > 1) {
    print("<a href=\"index_i.php?page=1\">Ƭ</a> ");
    print("<a href=\"index_i.php?page=" . ($current - 1) . "\"></a> ");
  }
  print("${current}/${pages} ");
  if ($current < $pages) {
    print("<a href=\"index_i.php?page=" . ($current + 1) . "\"></a>");
  }
  print("<br><hr>\n");

  // ɽ
  if (count($fileArray) > 0) {
    print("<ul>");
    for ($i = $imgStart; $i < $imgEnd; $i++) {

      $filePtr = fopen("${dirName}Messages/${fileArray[$i]}_mes.txt", "r");
      $pizza = fgets($filePtr, 1024);
      $pizza = htmlspecialchars($pizza);
      $piece = explode("|||", $pizza);
      fclose($filePtr);

      if (mb_strlen($piece[2]) > 8) {
        $piece[2] = mb_substr($piece[2], 0, 7) . "";
      }
      if (mb_strlen($piece[3]) > 10) {
        $piece[3] = mb_substr($piece[3], 0, 7) . "";
      }

      print("<li><a href=\"index_i.php?img=${i}&page=${current}\">");
      print("${piece[2]}</a> ${piece[3]}\n");
    }
    print("</ul>");
  } else {
    print("NO IMAGE!");
  }
}

// ξܺپɽ
if (isset($_GET['img'])) {
  $imgName = $fileArray[$_GET['img']];

  print("ɽ \n");
  print("<a href=\"index_i.php?page=1\">");
  print("[]</a><br>");
  if ($_GET['img'] > 0) {
    print("<a href=\"index_i.php?img=0\">");
    print("Ƭ</a> ");
    print("<a href=\"index_i.php?img=" . ($_GET['img'] - 1) . "\">");
    print("</a> ");
  }
  print(($_GET['img'] + 1) . "/" . count($fileArray) . " ");
  if (($_GET['img'] + 1) < count($fileArray)) {
    print("<a href=\"index_i.php?img=" . ($_GET['img'] + 1) . "\">");
    print("</a>");
  }
  print("<br><hr>\n");

  $mesText = file("${dirName}Messages/${imgName}_mes.txt");
  $mesElem = explode("|||", $mesText[0]);

  print("<center>");
  if (eregi("\.gif$", $imgName)) {
    print("<img src=\"${picUrl}${imgName}\" " .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">\n");
  } else {
    print("<img src=\"${picUrl}Thumbnails/{$imgName}_thumb.jpg\" " .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">\n");
  }
  print("</center>");

  $mesElem[2] = htmlspecialchars($mesElem[2]);
  print("<br>̾:${mesElem[2]}<br>");
  print("̾:");
  if ($mesElem[4] != "NOMAIL") {
    $mesElem[4] = htmlspecialchars($mesElem[4]);
    print("<a href=\"mailto:${mesElem[4]}\">");
  }
  $mesElem[3] = htmlspecialchars($mesElem[3]);
  print("${mesElem[3]}");
  if ($mesElem[4] != "NOMAIL") {
    print("</a>");
  }
  $mesElem[5] = substr($mesElem[5], 5, -3);
  print("<br>:${mesElem[5]}<br>\n");
  print(":<br>\n");
  if (!ereg("^NOCOM(\r\n|\r|\n)$", $mesElem[7])) {
    $mesElem[7] = messageParse($mesElem[7]);
    print("${mesElem[7]}\n");
  }

  // Ȥɽ
  print("<hr>:<br>");
  if (count($mesText) > 1) {
    for ($i = 1; $i < count($mesText); $i++) {
      $repElem = explode("|||", $mesText[$i]);
      $repElem[0] = htmlspecialchars($repElem[0]);
      $repElem[1] = messageParse($repElem[1]);
      print("<font color=\"#808000\">[${repElem[0]}]</font>${repElem[1]}<br>\n");
    }
  }

  echo <<<EOD
<form action="./comment_i.php" method="GET">
<input type="hidden" name="repNum" value="${_GET['img']}">
<input type="hidden" name="repImg" value="${imgName}">
<hr>̾<br><input type="text" name="repName" size="15"><br>
<br><textarea name="repCom" rows="3" cols="15"></textarea><br>
<input type="submit" value=""><input type="reset" value="ꥻå">
</form>
EOD;

}
?>


<hr>
<center>
BBWA-0.0.4
</center>
</body>
</html>

==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/index_i.php <==
<?php
//
// BBWA
// index_i.php
// Хࡦեʤɤɽ ()
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<html>
<head>
<title>BBWA</title>
</head>
<body>


<?php
include("variables.php");
$fileArray = array();

// ĥԤ
function messageParse($message) {
  $message = stripslashes($message);
  $message = ereg_replace(
    "(http|https|ftp|mailto):[a-zA-Z0-9/%&=_:+~@\-\?\.]*",
    "<a href=\"\\0\">\\0</a>", $message);
  $message = ereg_replace("{{BR}}", "<br>", $message);
  $message = ereg_replace("{{LT}}", "&lt;", $message);
  $message = ereg_replace("{{GT}}", "&gt;", $message);

  return $message;
}

// ǥåɤ߹
$tempArray = array();
$filePtr = fopen("${dirName}INDEX", "r");
while ($pizza = fgets($filePtr, 1024)) {
  $piece = explode("|||", $pizza);
  $tempArray[$piece[0]] = $piece[1];
}
arsort($tempArray);
$fileArray = array_keys($tempArray);
fclose($filePtr);

// ڡ׻
$pages = (int) ((count($fileArray) - 1) / 20 + 1);
if (isset($_GET['page'])) {
  $current = $_GET['page'];
} else {
  $current = 1;
}
$imgStart = ($current - 1) * 20;
$imgEnd = min(($imgStart + 20), count($fileArray));

// SJIS ǽ
mb_http_output("SJIS");
ob_start(mb_output_handler);

if(!isset($_GET['img'])) {
  // ڡΥɽ
  print("ɽ<br>\n");
  if ($current > 1) {
    print("<a href=\"index_i.php?page=1\">Ƭ</a> ");
    print("<a href=\"index_i.php?page=" . ($current - 1) . "\"></a> ");
  }
  print("${current}/${pages} ");
  if ($current < $pages) {
    print("<a href=\"index_i.php?page=" . ($current + 1) . "\"></a>");
  }
  print("<br><hr>\n");

  // ɽ
  if (count($fileArray) > 0) {
    print("<ul>");
    for ($i = $imgStart; $i < $imgEnd; $i++) {

      $filePtr = fopen("${dirName}Messages/${fileArray[$i]}_mes.txt", "r");
      $pizza = fgets($filePtr, 1024);
      $pizza = htmlspecialchars($pizza);
      $piece = explode("|||", $pizza);
      fclose($filePtr);

      if (mb_strlen($piece[2]) > 8) {
        $piece[2] = mb_substr($piece[2], 0, 7) . "";
      }
      if (mb_strlen($piece[3]) > 10) {
        $piece[3] = mb_substr($piece[3], 0, 7) . "";
      }

      print("<li><a href=\"index_i.php?img=${fileArray[$i]}&page=${current}\">");
      print("${piece[2]}</a> ${piece[3]}\n");
    }
    print("</ul>");
  } else {
    print("NO IMAGE!");
  }
} else {
  $num = array_search($_GET['img'], $fileArray);

  // ڡΥɽ
  print("ɽ \n");
  print("<a href=\"index_i.php?page=1\">");
  print("[]</a><br>");
  if ($num > 0) {
    print("<a href=\"index_i.php?img=${fileArray[0]}\">");
    print("Ƭ</a> ");
    print("<a href=\"index_i.php?img=" . $fileArray[$num - 1] . "\">");
    print("</a> ");
  }
  print(($num + 1) . "/" . count($fileArray) . " ");
  if (($num + 1) < count($fileArray)) {
    print("<a href=\"index_i.php?img=" . $fileArray[$num + 1] . "\">");
    print("</a>");
  }
  print("<br><hr>\n");

  // ξܺپɽ
  $mesText = file("${dirName}Messages/${_GET['img']}_mes.txt");
  $mesElem = explode("|||", $mesText[0]);

  print("<center>");
  if (eregi("\.gif$", $_GET['img'])) {
    print("<img src=\"${picUrl}${_GET['img']}\" " .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">\n");
  } else {
    print("<img src=\"${picUrl}Thumbnails/${_GET['img']}_thumb.jpg\" " .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">\n");
  }
  print("</center>");

  $mesElem[2] = htmlspecialchars($mesElem[2]);
  print("<br>̾:${mesElem[2]}<br>");
  print("̾:");
  if ($mesElem[4] != "NOMAIL") {
    $mesElem[4] = htmlspecialchars($mesElem[4]);
    print("<a href=\"mailto:${mesElem[4]}\">");
  }
  $mesElem[3] = htmlspecialchars($mesElem[3]);
  print("${mesElem[3]}");
  if ($mesElem[4] != "NOMAIL") {
    print("</a>");
  }
  $mesElem[5] = substr($mesElem[5], 5, -3);
  print("<br>:${mesElem[5]}<br>\n");
  print(":<br>\n");
  if (!ereg("^NOCOM(\r\n|\r|\n)$", $mesElem[7])) {
    $mesElem[7] = messageParse($mesElem[7]);
    print("${mesElem[7]}\n");
  }

  // Ȥɽ
  print("<hr>:<br>");
  if (count($mesText) > 1) {
    for ($i = 1; $i < count($mesText); $i++) {
      $repElem = explode("|||", $mesText[$i]);
      $repElem[0] = htmlspecialchars($repElem[0]);
      $repElem[1] = messageParse($repElem[1]);
      print("<font color=\"#808000\">[${repElem[0]}]</font>${repElem[1]}<br>\n");
    }
  }

  echo <<<EOD
<form action="./comment_i.php" method="GET">
<input type="hidden" name="repImg" value="${_GET['img']}">
<hr>̾<br><input type="text" name="repName" size="15"><br>
<br><textarea name="repCom" rows="3" cols="15"></textarea><br>
<input type="submit" value=""><input type="reset" value="ꥻå">
</form>
EOD;

}
?>


<hr>
<center>
BBWA-0.0.4
</center>
</body>
</html>
